@@ -40,7 +40,7 @@ class Exceptions:
 
 class ForecastQueryServiceClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/forecastquery.html#ForecastQueryService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecastquery.html#ForecastQueryService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html)
     """
 
@@ -56,21 +56,21 @@ class ForecastQueryServiceClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html#can_paginate)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html#generate_presigned_url)
         """
 
@@ -79,13 +79,13 @@ class ForecastQueryServiceClient(BaseClient):
         *,
         ForecastArn: str,
         Filters: Mapping[str, str],
-        StartDate: str = None,
-        EndDate: str = None,
-        NextToken: str = None
+        StartDate: str = ...,
+        EndDate: str = ...,
+        NextToken: str = ...
     ) -> QueryForecastResponseTypeDef:
         """
         Retrieves a forecast for a single item, filtered by the supplied criteria.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html#query_forecast)
         """
